Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version = "dev"
Version is the current release version, injected via ldflags at build time. Defaults to "dev" for local builds.
Functions ¶
func SetChatOutputForTest ¶
func SetSharedForTest ¶
func SetSharedForTest(sc *SharedConfig) func()
SetSharedForTest sets the global shared config to a test-specific value and returns a cleanup function that restores the previous state. Tests should defer the cleanup:
defer SetSharedForTest(&SharedConfig{APIKey: "test", ...})()
Types ¶
type SharedConfig ¶
type SharedConfig struct {
}
SharedConfig holds all shared configuration values that were previously individual global variables. Initialized in PersistentPreRunE.
Source Files
¶
- audio.go
- audio_helpers.go
- audio_init.go
- audio_request.go
- background.go
- background_rmbg_init.go
- balance.go
- chat.go
- chat_agent.go
- chat_defs.go
- chat_exec.go
- chat_query.go
- chat_request.go
- detect.go
- detect_helpers.go
- detect_init.go
- detect_runner.go
- detect_watermark.go
- ideas.go
- ideas_cache.go
- ideas_images.go
- ideas_init.go
- ideas_output.go
- image.go
- image_dispatch.go
- image_helpers.go
- image_request.go
- image_runners.go
- mcp.go
- midjourney.go
- midjourney_actions.go
- midjourney_extra.go
- midjourney_imagine.go
- midjourney_request.go
- midjourney_shared.go
- models.go
- ocr.go
- preview.go
- root.go
- shared.go
- task.go
- tui.go
- tui_input.go
- tui_loop.go
- tui_view.go
- util.go
- version.go
- video.go
- video_dispatch.go
- video_helpers.go
- video_request.go
- video_runners.go
- vision.go
Click to show internal directories.
Click to hide internal directories.